<?php

namespace Hsin\Wechat\Func;

use Hsin\Wechat\WechatException;

/**
 * 菜单管理
 */
trait Menu
{
	/**
	 * 获取菜单
	 * 
	 * @return stdClass json
	 */
	public function getMenu()
	{
		$json = $this->http->getJson('https://api.weixin.qq.com/cgi-bin/menu/get', [
			'query' => [
				'access_token' => $this->getAccessToken(),
			]
		]);

		$this->exceptionOrNot($json);

		return $json;
	}

	/**
	 * 获取任何方式创建的菜单
	 * 
	 * @return stdClass json
	 */
	public function getMenuAnyWay()
	{
		$json = $this->http->getJson('https://api.weixin.qq.com/cgi-bin/get_current_selfmenu_info', [
			'query' => [
				'access_token' => $this->getAccessToken(),
			]
		]);

		$this->exceptionOrNot($json);

		return $json;
	}
	
	/**
	 * 创建菜单
	 * 
	 * @param  string or array $menu  菜单数据
	 * @return bool                   是否创建成功
	 */
	public function createMenu($menu)
	{
		$json = $this->http->postJson('https://api.weixin.qq.com/cgi-bin/menu/create', [
			'query' => [
				'access_token' => $this->getAccessToken(),
			],
			'body' => is_string($menu) ? $menu : json_encode($menu, JSON_UNESCAPED_UNICODE),
		]);

		$this->exceptionOrNot($json);

		return true;
	}

	/**
	 * 删除菜单
	 * 
	 * @return bool 是否删除成功
	 */
	public function deleteMenu()
	{
		$json = $this->http->getJson('https://api.weixin.qq.com/cgi-bin/menu/delete', [
			'query' => [
				'access_token' => $this->getAccessToken(),
			]
		]);

		$this->exceptionOrNot($json);

		return true;
	}
}